@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use CPAN::Meta;
 use Carp;
@@ -253,8 +253,12 @@ sub _build_github_user {
     my $self = shift;
 
     my $name = $self->_git_config->{'github.user'};
-    ($name) //= ( $self->_git_config->{'remote.origin.url'} // q{} )
-        =~ m{github\.com[:/]([^/]+)};
+    if ( !defined $name
+        && ( $self->_git_config->{'remote.origin.url'} // q{} )
+        =~ m{github\.com[:/]([^/]+)} ) {
+
+        $name = $1;
+    }
 
     $name = IO::Prompt::Tiny::prompt( 'GitHub user:', ( $name // q{} ) )
         if $self->prompt;
@@ -743,7 +747,7 @@ RTx::ToGitHub - Convert rt.cpan.org tickets to GitHub issues
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
